@@ -12,6 +12,7 @@ from featurExtract.commands.extract_uORF import get_uorf
 from featurExtract.commands.extract_dORF import get_dorf
 from featurExtract.commands.extract_CDS import get_cds
 from featurExtract.commands.extract_promoter import get_promoter
+from featurExtract.commands.extract_terminator import get_terminator
 from featurExtract.commands.extract_exon import get_exon
 from featurExtract.commands.extract_intron import get_intron
 from featurExtract.commands.extract_gene import get_gene
@@ -99,6 +100,13 @@ def promoter(args):
     '''
     get_promoter(args)
 
+def terminator(args):
+    '''
+    parameters:
+     args: arguments from argparse
+    '''
+    get_terminator(args)
+
 def gene(args):
     '''
     parameters:
@@ -159,6 +167,27 @@ parser_promoter.add_argument('-p', '--print', action="store_true",
                              help = 'output to stdout')
 parser_promoter.set_defaults(func=promoter)
 
+
+# terminator 
+parser_terminator = subparsers.add_parser('terminator', help='extract terminator in genome or gene')
+parser_terminator.add_argument('-d', '--database', type=str, required=True,
+                             help='database generated by subcommand create')
+parser_terminator.add_argument('-f', '--genome', type=str, required=True,
+                             help='genome fasta path')
+parser_terminator.add_argument('-g', '--gene', type=str,
+                             help='specific gene; if not given, return whole genes')
+parser_terminator.add_argument('-l', '--terminator_length', type=int, default=0,
+                             help='terminator length')
+parser_terminator.add_argument('-u', '--utr3_upper_length', type=int, default=0,
+                             help='utr3 length')
+parser_terminator.add_argument('-o', '--output', type=str,
+                             help = 'output file path')
+parser_terminator.add_argument('--output_format', type=str, choices=['csv','fasta'],
+                             help = 'output format')
+parser_terminator.add_argument('-p', '--print', action="store_true",
+                             help = 'output to stdout')
+parser_terminator.set_defaults(func=terminator)
+
 # gene subcommand 
 parser_gene = subparsers.add_parser('gene', help='extract gene in genome or gene')
 parser_gene.add_argument('-d', '--database', type=str, required=True,
